==> ogre-docs-1.11.2-1-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/_scripts.js <==
var _scripts =
[
    [ "Format", "_scripts.html#Format", [
      [ "Script Inheritance", "_scripts.html#Script-Inheritance", [
        [ "Advanced Script Inheritance", "_scripts.html#Advanced-Script-Inheritance", null ]
      ] ],
      [ "Script Variables", "_scripts.html#Script-Variables", null ],
      [ "Script Import Directive", "_scripts.html#Script-Import-Directive", null ]
    ] ],
    [ "Custom Translators", "_scripts.html#custom-translators", null ],
    [ "Material Scripts", "_material-_scripts.html", [
      [ "Material", "_material-_scripts.html#Material", null ],
      [ "Techniques", "_material-_scripts.html#Techniques", null ],
      [ "Passes", "_material-_scripts.html#Passes", [
        [ "iteration", "_material-_scripts.html#iteration", null ]
      ] ],
      [ "Texture Units", "_material-_scripts.html#Texture-Units", null ],
      [ "Declaring GPU Programs", "_material-_scripts.html#Declaring-Vertex_002fGeometry_002fFragment-Programs", null ],
      [ "Specifying Named Constants for Assembler Shaders", "_material-_scripts.html#Specifying-Named-Constants-for-Assembler-Shaders", null ],
      [ "Default Program Parameters", "_material-_scripts.html#Default-Program-Parameters", null ],
      [ "Declaring Shared Parameters", "_material-_scripts.html#Declaring-Shared-Parameters", null ],
      [ "Adding new Techniques, Passes, to copied materials", "_material-_scripts.html#Adding-new-Techniques_002c-Passes_002c-to-copied-materials_003a", null ],
      [ "Identifying Texture Units to override values", "_material-_scripts.html#Identifying-Texture-Units-to-override-values", null ],
      [ "Texture Aliases", "_material-_scripts.html#Texture-Aliases", null ]
    ] ],
    [ "Compositor Scripts", "_compositor-_scripts.html", [
      [ "Compositor Fundamentals", "_compositor-_scripts.html#Compositor-Fundamentals", null ],
      [ "Format", "_compositor-_scripts.html#Format-1", [
        [ "Techniques", "_compositor-_scripts.html#Compositor-Techniques", null ],
        [ "Target Passes", "_compositor-_scripts.html#Compositor-Target-Passes", null ],
        [ "Compositor Passes", "_compositor-_scripts.html#Compositor-Passes", null ]
      ] ],
      [ "Clear Section", "_compositor-_scripts.html#Clear-Section", null ],
      [ "Stencil Section", "_compositor-_scripts.html#Stencil-Section", null ],
      [ "Applying a Compositor", "_compositor-_scripts.html#Applying-a-Compositor", null ]
    ] ],
    [ "Particle Scripts", "_particle-_scripts.html", [
      [ "Particle Emitters", "_particle-_scripts.html#Particle-Emitters", null ],
      [ "Standard Particle Emitters", "_particle-_scripts.html#Standard-Particle-Emitters", [
        [ "Point Emitter", "_particle-_scripts.html#Point-Emitter", null ],
        [ "Box Emitter", "_particle-_scripts.html#Box-Emitter", null ],
        [ "Cylinder Emitter", "_particle-_scripts.html#Cylinder-Emitter", null ],
        [ "Ellipsoid Emitter", "_particle-_scripts.html#Ellipsoid-Emitter", null ],
        [ "Hollow Ellipsoid Emitter", "_particle-_scripts.html#Hollow-Ellipsoid-Emitter", null ],
        [ "Ring Emitter", "_particle-_scripts.html#Ring-Emitter", null ],
        [ "Emitting Emitters", "_particle-_scripts.html#Emitting-Emitters", null ]
      ] ],
      [ "Particle Affectors", "_particle-_scripts.html#Particle-Affectors", null ],
      [ "Standard Particle Affectors", "_particle-_scripts.html#Standard-Particle-Affectors", [
        [ "Linear Force Affector", "_particle-_scripts.html#Linear-Force-Affector", null ],
        [ "ColourFader Affector", "_particle-_scripts.html#ColourFader-Affector", null ],
        [ "ColourFader2 Affector", "_particle-_scripts.html#ColourFader2-Affector", null ],
        [ "Scaler Affector", "_particle-_scripts.html#Scaler-Affector", null ],
        [ "Rotator Affector", "_particle-_scripts.html#Rotator-Affector", null ],
        [ "ColourInterpolator Affector", "_particle-_scripts.html#ColourInterpolator-Affector", null ],
        [ "ColourImage Affector", "_particle-_scripts.html#ColourImage-Affector", null ],
        [ "DeflectorPlane Affector", "_particle-_scripts.html#DeflectorPlane-Affector", null ],
        [ "DirectionRandomiser Affector", "_particle-_scripts.html#DirectionRandomiser-Affector", null ]
      ] ]
    ] ],
    [ "Overlay Scripts", "_overlay-_scripts.html", [
      [ "Adding elements to the overlay", "_overlay-_scripts.html#Adding-elements-to-the-overlay", null ],
      [ "Templates", "_overlay-_scripts.html#Templates", null ],
      [ "Standard OverlayElements", "_overlay-_scripts.html#Standard-OverlayElements", [
        [ "Panel", "_overlay-_scripts.html#Panel", null ],
        [ "BorderPanel", "_overlay-_scripts.html#BorderPanel", null ],
        [ "TextArea", "_overlay-_scripts.html#TextArea", null ]
      ] ]
    ] ],
    [ "Font Definition Scripts", "_font-_definition-_scripts.html", null ]
];

==> ogre-docs-1.11.5-1-x86_64.pkg.tar.xz: usr/share/doc/OGRE/api/html/_scripts.js <==
var _scripts =
[
    [ "Format", "_scripts.html#Format", [
      [ "Script Inheritance", "_scripts.html#Script-Inheritance", [
        [ "Advanced Script Inheritance", "_scripts.html#Advanced-Script-Inheritance", null ]
      ] ],
      [ "Script Variables", "_scripts.html#Script-Variables", null ],
      [ "Script Import Directive", "_scripts.html#Script-Import-Directive", null ]
    ] ],
    [ "Custom Translators", "_scripts.html#custom-translators", null ],
    [ "Material Scripts", "_material-_scripts.html", [
      [ "Material", "_material-_scripts.html#Material", null ],
      [ "Techniques", "_material-_scripts.html#Techniques", null ],
      [ "Passes", "_material-_scripts.html#Passes", [
        [ "iteration", "_material-_scripts.html#iteration", null ]
      ] ],
      [ "Texture Units", "_material-_scripts.html#Texture-Units", null ],
      [ "Samplers", "_material-_scripts.html#Samplers", null ],
      [ "Declaring GPU Programs", "_material-_scripts.html#Declaring-Vertex_002fGeometry_002fFragment-Programs", null ],
      [ "Specifying Named Constants for Assembler Shaders", "_material-_scripts.html#Specifying-Named-Constants-for-Assembler-Shaders", null ],
      [ "Default Program Parameters", "_material-_scripts.html#Default-Program-Parameters", null ],
      [ "Declaring Shared Parameters", "_material-_scripts.html#Declaring-Shared-Parameters", null ],
      [ "Adding new Techniques, Passes, to copied materials", "_material-_scripts.html#Adding-new-Techniques_002c-Passes_002c-to-copied-materials_003a", null ],
      [ "Identifying Texture Units to override values", "_material-_scripts.html#Identifying-Texture-Units-to-override-values", null ],
      [ "Texture Aliases", "_material-_scripts.html#Texture-Aliases", null ]
    ] ],
    [ "Compositor Scripts", "_compositor-_scripts.html", [
      [ "Compositor Fundamentals", "_compositor-_scripts.html#Compositor-Fundamentals", null ],
      [ "Techniques", "_compositor-_scripts.html#Compositor-Techniques", [
        [ "texture", "_compositor-_scripts.html#compositor-texture", null ]
      ] ],
      [ "Target Passes", "_compositor-_scripts.html#Compositor-Target-Passes", null ],
      [ "Compositor Passes", "_compositor-_scripts.html#Compositor-Passes", [
        [ "Clear Section", "_compositor-_scripts.html#Clear-Section", null ],
        [ "Stencil Section", "_compositor-_scripts.html#Stencil-Section", null ]
      ] ],
      [ "Applying a Compositor", "_compositor-_scripts.html#Applying-a-Compositor", null ]
    ] ],
    [ "Particle Scripts", "_particle-_scripts.html", [
      [ "Particle Emitters", "_particle-_scripts.html#Particle-Emitters", null ],
      [ "Standard Particle Emitters", "_particle-_scripts.html#Standard-Particle-Emitters", [
        [ "Point Emitter", "_particle-_scripts.html#Point-Emitter", null ],
        [ "Box Emitter", "_particle-_scripts.html#Box-Emitter", null ],
        [ "Cylinder Emitter", "_particle-_scripts.html#Cylinder-Emitter", null ],
        [ "Ellipsoid Emitter", "_particle-_scripts.html#Ellipsoid-Emitter", null ],
        [ "Hollow Ellipsoid Emitter", "_particle-_scripts.html#Hollow-Ellipsoid-Emitter", null ],
        [ "Ring Emitter", "_particle-_scripts.html#Ring-Emitter", null ],
        [ "Emitting Emitters", "_particle-_scripts.html#Emitting-Emitters", null ]
      ] ],
      [ "Particle Affectors", "_particle-_scripts.html#Particle-Affectors", null ],
      [ "Standard Particle Affectors", "_particle-_scripts.html#Standard-Particle-Affectors", [
        [ "Linear Force Affector", "_particle-_scripts.html#Linear-Force-Affector", null ],
        [ "ColourFader Affector", "_particle-_scripts.html#ColourFader-Affector", null ],
        [ "ColourFader2 Affector", "_particle-_scripts.html#ColourFader2-Affector", null ],
        [ "Scaler Affector", "_particle-_scripts.html#Scaler-Affector", null ],
        [ "Rotator Affector", "_particle-_scripts.html#Rotator-Affector", null ],
        [ "ColourInterpolator Affector", "_particle-_scripts.html#ColourInterpolator-Affector", null ],
        [ "ColourImage Affector", "_particle-_scripts.html#ColourImage-Affector", null ],
        [ "DeflectorPlane Affector", "_particle-_scripts.html#DeflectorPlane-Affector", null ],
        [ "DirectionRandomiser Affector", "_particle-_scripts.html#DirectionRandomiser-Affector", null ]
      ] ]
    ] ],
    [ "Overlay Scripts", "_overlay-_scripts.html", [
      [ "Adding elements to the overlay", "_overlay-_scripts.html#Adding-elements-to-the-overlay", null ],
      [ "Templates", "_overlay-_scripts.html#Templates", null ],
      [ "Standard OverlayElements", "_overlay-_scripts.html#Standard-OverlayElements", [
        [ "Panel (container)", "_overlay-_scripts.html#Panel", null ],
        [ "BorderPanel (container)", "_overlay-_scripts.html#BorderPanel", null ],
        [ "TextArea (element)", "_overlay-_scripts.html#TextArea", null ]
      ] ]
    ] ],
    [ "Font Definition Scripts", "_font-_definition-_scripts.html", null ]
];
